@@ -290,30 +290,6 @@ mod test {
         });
     }
 
-    #[test]
-    fn test_insert_order() {
-        rbatis::core::runtime::task::block_on(async {
-            fast_log::init_log("requests.log", 1000, log::Level::Info, None, true);
-            let mut rb = Rbatis::new();
-            //设置 逻辑删除插件
-            rb.logic_plugin = Some(Box::new(RbatisLogicDeletePlugin::new("delete_flag")));
-            rb.link("mysql://root:123456@localhost:3306/test")
-                .await
-                .unwrap();
-
-            let py_sql = r#"
-                        update user set name=#{name}, password=#{password} ,sex=#{sex}, phone=#{phone}, delete_flag=#{flag},
-                        create_datetime=current_timestamp(), update_datetime=current_timestamp() where id=#{id}
-                    "#;
-            let (sql, args) = rb.runtime_py.eval(&rb.driver_type().unwrap(), py_sql, &mut serde_json::json!({"name":"name", "password":"ps_encode","sex": "sex", "phone": "phone", "flag":0, "id": "u.id"}), &rb.runtime_expr).unwrap();
-            assert_eq!(sql, "update user set name=?, password=? ,sex=?, phone=?, delete_flag=?, create_datetime=current_timestamp(), update_datetime=current_timestamp() where id=?");
-            assert_eq!(
-                serde_json::json!(args).to_string(),
-                serde_json::json!(["name", "ps_encode", "sex", "phone", 0, "u.id"]).to_string()
-            );
-        });
-    }
-
     #[tokio::test]
     pub async fn test_list_by_wrapper() {
         fast_log::init_log("requests.log", 1000, log::Level::Info, None, true);
